@@ -13,7 +13,7 @@ from flask_jwt_extended import (
 from python_helper import Constant as c
 from python_helper import log, Function, ObjectHelper, ReflectionHelper, SettingHelper, DateTimeHelper
 
-from python_framework.api.src.util import UtcDateTimeHelper
+from python_framework.api.src.helper import UtcDateTimeHelper
 from python_framework.api.src.converter.static import ConverterStatic
 from python_framework.api.src.constant import ConfigurationKeyConstant
 from python_framework.api.src.constant import JwtConstant
